==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ListPanelItemModelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescription } from "./ListPanelItemModelDescription";
/**
 * @hidden
 */
export let ListPanelItemModelDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelItemModelDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelItemModelDescriptionMetadata.a == null) {
                ListPanelItemModelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelItemModelDescriptionMetadata.c(ListPanelItemModelDescriptionMetadata.a);
            }
            if (a.k(ListPanelItemModelDescriptionMetadata.a)) {
                return;
            }
            a.ab(ListPanelItemModelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("RowHeight", "Number:double");
            a.item("RowObjectRef", "(w:RowObject,wf:RowObject)DataRef");
            a.item("IsModelDirty", "Boolean");
        }
        static d(a) {
            ListPanelItemModelDescriptionMetadata.b(a);
            a.ad("ListPanelItemModel", () => new ListPanelItemModelDescription());
            a.ac("ListPanelItemModel", ListPanelItemModelDescriptionMetadata.a);
        }
    }
    ListPanelItemModelDescriptionMetadata.$t = markType(ListPanelItemModelDescriptionMetadata, 'ListPanelItemModelDescriptionMetadata');
    ListPanelItemModelDescriptionMetadata.a = null;
    return ListPanelItemModelDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ListPanelItemModelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescription } from "./ListPanelItemModelDescription";
/**
 * @hidden
 */
export let ListPanelItemModelDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelItemModelDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelItemModelDescriptionMetadata.a == null) {
                ListPanelItemModelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelItemModelDescriptionMetadata.c(ListPanelItemModelDescriptionMetadata.a);
            }
            if (a.k(ListPanelItemModelDescriptionMetadata.a)) {
                return;
            }
            a.ac(ListPanelItemModelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("RowHeight", "Number:double");
            a.item("RowObjectRef", "(w:RowObject,wf:RowObject)DataRef");
            a.item("IsModelDirty", "Boolean");
            a.item("Left", "Number:double");
            a.item("Top", "Number:double");
            a.item("IsActivated", "Boolean");
            a.item("IsActivationSupported", "Boolean");
            a.item("IsSelected", "Boolean");
        }
        static d(a) {
            ListPanelItemModelDescriptionMetadata.b(a);
            a.ae("ListPanelItemModel", () => new ListPanelItemModelDescription());
            a.ad("ListPanelItemModel", ListPanelItemModelDescriptionMetadata.a);
        }
    }
    ListPanelItemModelDescriptionMetadata.$t = markType(ListPanelItemModelDescriptionMetadata, 'ListPanelItemModelDescriptionMetadata');
    ListPanelItemModelDescriptionMetadata.a = null;
    return ListPanelItemModelDescriptionMetadata;
})();
